/**
 * This work was created by participants in the DataONE project, and is
 * jointly copyrighted by participating institutions in DataONE. For 
 * more information on DataONE, see our web site at http://dataone.org.
 *
 *   Copyright ${year}
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 * 
 * $Id$
 */
package org.dataone.tidy.dao;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dataone.configuration.Settings;
import org.hibernate.annotations.Index;

/**
 * 
 * ChangeRecord is configured via Spring framework as a spring-data JPA object and
 * is stored in relational datastore.
 * 
 * @author rnahf
 * @author sroseboo
 *
 */

@Entity
@Table(name = "change_record")
public class ChangeRecord implements Serializable {

    private static final long serialVersionUID = 995840092901314022L;
    private static final Long RUN_ID = Settings.getConfiguration().getLong("tidy.run.id", 999);

    @Transient
    private static final Log log = LogFactory.getLog(ChangeRecord.class);

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @Column(columnDefinition = "TEXT", nullable = false)
    private String pid;

    @Index(name = "index_run")
    @Column
    private Long runId = RUN_ID;

    @Column(columnDefinition = "TEXT")
    private String attribute;

    @Column(columnDefinition = "TEXT")
    private String cnORC;

    @Column(columnDefinition = "TEXT")
    private String cnUCSB;

    @Column(columnDefinition = "TEXT")
    private String cnUNM;

    @Column(columnDefinition = "TEXT")
    private String authMN;

    @Column(columnDefinition = "TEXT")
    private String resulting;

    private String changeRule;

    // default constructor required by jpa
    public ChangeRecord() {
    }

    public ChangeRecord(String pidValue) {
        this.pid = pidValue;
    }

    public String getAttribute() {
        return this.attribute;
    }

    public String getCnORC() {
        return this.cnORC;
    }

    public String getCnUCSB() {
        return this.cnUCSB;
    }

    public String getCnUNM() {
        return this.cnUNM;
    }

    public String getResulting() {
        return this.resulting;
    }

    public String getChangeRule() {
        return this.changeRule;
    }

    public void setAttribute(String attribute) {
        this.attribute = attribute;
    }

    public void setCnORC(String cnORCvalue) {
        this.cnORC = cnORCvalue;
    }

    public void setCnUCSB(String cnUCSBvalue) {
        this.cnUCSB = cnUCSBvalue;
    }

    public void setCnUNM(String cnUNMvalue) {
        this.cnUNM = cnUNMvalue;
    }

    public void setResulting(String resulting) {
        this.resulting = resulting;
    }

    public void setChangeRule(String changeRule) {
        this.changeRule = changeRule;
    }

    public Long getId() {
        return id;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getAuthMN() {
        return authMN;
    }

    public void setAuthMN(String authMN) {
        this.authMN = authMN;
    }

    public Long getRunId() {
        return runId;
    }

    public void setRunId(Long runId) {
        this.runId = runId;
    }

    @Override
    public String toString() {
        return "ChangeRecord [id=" + id + ", pid=" + pid + ", runId=" + runId + ", attribute="
                + attribute + ", authMN=" + authMN + ", changeRule=" + changeRule + ", cnOrc="
                + cnORC + ", cnUcsb=" + cnUCSB + ", cnUnm=" + cnUNM + ", resulting=" + resulting
                + "]";
    }
}
