#!/bin/bash

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2014
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Dumps tidy merged metadata related tables from the Coordinating Node that the script is run on into a
# .sql dump file.
# 2) Modifies the SQL dump to remove a 'merged_' prefix to entity names 
# 3) Transfers the SQL dump in bulk via rsync to the target machine where the dump will be restored
# to create the new per-CN tables where the tidy merging will happen.
# Note that transferring  and running the SQL dump script on the target machine is a manual step.

DUMP_DATE=$(date +%F-%H%M);
DUMP_CMD="/usr/bin/pg_dump";

DUMP_DB="metacat";
DUMP_DIR="/var/lib/postgresql/pg_tidy_dump";
DUMP_FILE="${DUMP_DIR}/metacat_sysmeta.${DUMP_DATE}.dump";
DUMP_ERR="${DUMP_DIR}/metacat_sysmeta.${DUMP_DATE}.err";
DUMP_OPTS="-Fc \
-h localhost \
-w \
-t smreplicationpolicy \
-t smreplicationstatus \
-t systemmetadata \
-t xml_access \
-f ${DUMP_FILE} \
-U metacat";
if [[ ! -d ${DUMP_DIR} ]]; then
    mkdir ${DUMP_DIR};
    chown -R postgres.postgres ${DUMP_DIR};
fi

DUMP_CMD="/usr/bin/pg_dump ${DUMP_OPTS} ${DUMP_DB}";

nohup su - postgres -c "${DUMP_CMD}" 2> ${DUMP_ERR} < /dev/null &

